@@ -1,6 +1,6 @@
 package MooseX::POE::Aliased;
-BEGIN {
-  $MooseX::POE::Aliased::VERSION = '0.213';
+{
+  $MooseX::POE::Aliased::VERSION = '0.215';
 }
 # ABSTRACT: A sane alias attribute for your MooseX::POE objects.
 use MooseX::POE::Role;
@@ -17,16 +17,20 @@ has alias => (
     predicate   => "has_alias",
     trigger => sub {
         my ( $self, $alias ) = @_;
+
+        # we cannot set the alias UNTIL we construct the object!
+        # or ASSERT_DEFAULT will complain...
+        return unless defined $self->get_session_id;
         $self->call( _update_alias => $alias );
     }
 );
 
-sub BUILD {
+before 'STARTALL' => sub {
     my ($self) = @_;
 
     $self->call( _update_alias => $self->alias )
       if $self->has_alias;
-}
+};
 
 sub _build_alias {
     my $self = shift;
@@ -38,9 +42,10 @@ event _update_alias => sub {
 
     # we need to remove the prev alias like this because we don't know the
     # previous value.
-    $kernel->alarm_remove_all();
+    $kernel->alias_remove($_) for $kernel->alias_list( $self->get_session_id );
+    $kernel->alias_set($alias) if defined $alias;
 
-	$kernel->alias_set($alias) if defined $alias;
+    return;
 };
 
 __PACKAGE__;
@@ -55,7 +60,7 @@ MooseX::POE::Aliased - A sane alias attribute for your MooseX::POE objects.
 
 =head1 VERSION
 
-version 0.213
+version 0.215
 
 =head1 SYNOPSIS
 
